@@ -1,14 +1,5 @@
-#!/usr/bin/env python
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-
-import sys
-import os
-DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
-    '..', '..', '..', '..', '..', 'trytond')))
-if os.path.isdir(DIR):
-    sys.path.insert(0, os.path.dirname(DIR))
-
 import unittest
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import test_view, test_depends
@@ -16,29 +7,21 @@ from trytond.modules.party_siret import luhn
 
 
 class PartySiretTestCase(unittest.TestCase):
-    '''
-    Test PartySiret module.
-    '''
+    'Test PartySiret module'
 
     def setUp(self):
         trytond.tests.test_tryton.install_module('party_siret')
 
     def test0005views(self):
-        '''
-        Test views.
-        '''
+        'Test views'
         test_view('party_siret')
 
     def test0006depends(self):
-        '''
-        Test depends.
-        '''
+        'Test depends'
         test_depends()
 
     def test0010luhn(self):
-        '''
-        Test luhn.
-        '''
+        'Test luhn'
         values = (
                 (4111111111111111, True),
                 ('4111111111111111', True),
@@ -69,6 +52,3 @@ def suite():
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
         PartySiretTestCase))
     return suite
-
-if __name__ == '__main__':
-    unittest.TextTestRunner(verbosity=2).run(suite())
